AgreementRA

Enum AgreementRA 

pub enum AgreementRA<T> {
    Agree(T),
    Invalid,
}
The Agreement resource algebra

This resource algebra allows one to express that multiple parties can agree on a chosen value This is mainly useful to show that if two resources are Agree then they must point to the same value (see lemma_agree):

Variants



Agree(T)



Invalid

Implementations

Source

impl<T> AgreementRA<T>

pub fn arrow_0(self) -> T

pub fn arrow_Agree_0(self) -> T

Source

impl<T> AgreementRA<T>

pub open spec fn view(self) -> T

{ self->Agree_0 }