pub enum AgreementRA<T> {
Agree(T),
Invalid,
}Expand description
The Agreement resource algebra
This resource algebra allows one to express that multiple parties can agree on a chosen value
This is mainly useful to show that if two resources are Agree then they must point to the
same value (see lemma_agree):
Variants
Implementations
Sourceimpl<T> AgreementRA<T>
impl<T> AgreementRA<T>
pub fn arrow_0(self) -> T
pub fn arrow_Agree_0(self) -> T
Sourceimpl<T> AgreementRA<T>
impl<T> AgreementRA<T>